@@ -51,12 +51,12 @@
 
 #include "um-account-dialog.h"
 #include "um-language-dialog.h"
-#include "um-login-options.h"
 #include "um-password-dialog.h"
 #include "um-photo-dialog.h"
 #include "um-fingerprint-dialog.h"
 #include "um-utils.h"
-#include "gdm-languages.h"
+
+#include "cc-common-language.h"
 
 G_DEFINE_DYNAMIC_TYPE (UmUserPanel, um_user_panel, CC_TYPE_PANEL)
 
@@ -67,7 +67,7 @@ struct _UmUserPanelPrivate {
         UmUserManager *um;
         GtkBuilder *builder;
 
-        GtkWidget *notebook;
+        GtkWidget *main_box;
         GtkWidget *lock_button;
         GPermission *permission;
         GtkWidget *language_chooser;
@@ -75,7 +75,6 @@ struct _UmUserPanelPrivate {
         UmAccountDialog *account_dialog;
         UmPasswordDialog *password_dialog;
         UmPhotoDialog *photo_dialog;
-        UmLoginOptions *login_options;
 
         PolkitAuthority *authority;
 };
@@ -94,6 +93,7 @@ enum {
         TITLE_COL,
         HEADING_ROW_COL,
         SORT_KEY_COL,
+        AUTOLOGIN_COL,
         NUM_USER_LIST_COLS
 };
 
@@ -132,6 +132,7 @@ user_added (UmUserManager *um, UmUser *user, UmUserPanelPrivate *d)
         GtkTreeSelection *selection;
         gint sort_key;
         gchar *escaped_name;
+        gboolean is_autologin;
 
         g_debug ("user added: %d %s\n", um_user_get_uid (user), um_user_get_real_name (user));
         widget = get_widget (d, "list-treeview");
@@ -146,6 +147,8 @@ user_added (UmUserManager *um, UmUser *user, UmUserPanelPrivate *d)
                                 um_account_type_get_name (um_user_get_account_type (user)));
         g_free (escaped_name);
 
+        is_autologin = um_user_get_automatic_login (user);
+
         if (um_user_get_uid (user) == getuid ()) {
                 sort_key = 1;
         }
@@ -162,6 +165,7 @@ user_added (UmUserManager *um, UmUser *user, UmUserPanelPrivate *d)
                             TITLE_COL, NULL,
                             HEADING_ROW_COL, FALSE,
                             SORT_KEY_COL, sort_key,
+                            AUTOLOGIN_COL, is_autologin,
                             -1);
         g_object_unref (pixbuf);
         g_free (text);
@@ -257,6 +261,7 @@ user_changed (UmUserManager *um, UmUser *user, UmUserPanelPrivate *d)
         UmUser *current;
         GdkPixbuf *pixbuf;
         char *text;
+        gboolean is_autologin;
 
         tv = (GtkTreeView *)get_widget (d, "list-treeview");
         model = gtk_tree_view_get_model (tv);
@@ -270,11 +275,13 @@ user_changed (UmUserManager *um, UmUser *user, UmUserPanelPrivate *d)
                         text = g_strdup_printf ("<b>%s</b>\n<i>%s</i>",
                                                 um_user_get_display_name (user),
                                                 um_account_type_get_name (um_user_get_account_type (user)));
+                        is_autologin = um_user_get_automatic_login (user);
 
                         gtk_list_store_set (GTK_LIST_STORE (model), &iter,
                                             USER_COL, user,
                                             FACE_COL, pixbuf,
                                             NAME_COL, text,
+                                            AUTOLOGIN_COL, is_autologin,
                                             -1);
                         g_object_unref (pixbuf);
                         g_free (text);
@@ -329,7 +336,7 @@ static void
 add_user (GtkButton *button, UmUserPanelPrivate *d)
 {
         um_account_dialog_show (d->account_dialog,
-                                GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                                GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                 (UserCreatedCallback)select_created_user, d);
 }
 
@@ -345,7 +352,7 @@ delete_user_done (UmUserManager     *manager,
                 if (!g_error_matches (error, UM_USER_MANAGER_ERROR, UM_USER_MANAGER_ERROR_PERMISSION_DENIED)) {
                         GtkWidget *dialog;
 
-                        dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                        dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                          GTK_DIALOG_DESTROY_WITH_PARENT,
                                                          GTK_MESSAGE_ERROR,
                                                          GTK_BUTTONS_CLOSE,
@@ -405,7 +412,7 @@ delete_user (GtkButton *button, UmUserPanelPrivate *d)
                 return;
         }
         else if (um_user_get_uid (user) == getuid ()) {
-                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                  0,
                                                  GTK_MESSAGE_INFO,
                                                  GTK_BUTTONS_CLOSE,
@@ -414,7 +421,7 @@ delete_user (GtkButton *button, UmUserPanelPrivate *d)
                                   G_CALLBACK (gtk_widget_destroy), NULL);
         }
         else if (um_user_is_logged_in (user)) {
-                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                  0,
                                                  GTK_MESSAGE_INFO,
                                                  GTK_BUTTONS_CLOSE,
@@ -427,7 +434,7 @@ delete_user (GtkButton *button, UmUserPanelPrivate *d)
                                   G_CALLBACK (gtk_widget_destroy), NULL);
         }
         else {
-                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                  0,
                                                  GTK_MESSAGE_QUESTION,
                                                  GTK_BUTTONS_NONE,
@@ -486,6 +493,36 @@ get_password_mode_text (UmUser *user)
         return text;
 }
 
+static void
+autologin_changed (GObject            *object,
+                   GParamSpec         *pspec,
+                   UmUserPanelPrivate *d)
+{
+        gboolean active;
+        UmUser *user;
+
+        active = gtk_switch_get_active (GTK_SWITCH (object));
+        user = get_selected_user (d);
+
+        if (active != um_user_get_automatic_login (user)) {
+                um_user_set_automatic_login (user, active);
+                if (um_user_get_automatic_login (user)) {
+                        GSList *list;
+                        GSList *l;
+                        list = um_user_manager_list_users (d->um);
+                        for (l = list; l != NULL; l = l->next) {
+                                UmUser *u = l->data;
+                                if (um_user_get_uid (u) != um_user_get_uid (user)) {
+                                        um_user_set_automatic_login (user, FALSE);
+                                }
+                        }
+                        g_slist_free (list);
+                }
+        }
+
+        g_object_unref (user);
+}
+
 static void
 show_user (UmUser *user, UmUserPanelPrivate *d)
 {
@@ -518,8 +555,10 @@ show_user (UmUser *user, UmUserPanelPrivate *d)
         widget = get_widget (d, "account-password-button");
         um_editable_button_set_text (UM_EDITABLE_BUTTON (widget), get_password_mode_text (user));
 
-        widget = get_widget (d, "account-email-entry");
-        um_editable_entry_set_text (UM_EDITABLE_ENTRY (widget), um_user_get_email (user));
+        widget = get_widget (d, "autologin-switch");
+        g_signal_handlers_block_by_func (widget, autologin_changed, d);
+        gtk_switch_set_active (GTK_SWITCH (widget), um_user_get_automatic_login (user));
+        g_signal_handlers_unblock_by_func (widget, autologin_changed, d);
 
         widget = get_widget (d, "account-language-combo");
         model = um_editable_combo_get_model (UM_EDITABLE_COMBO (widget));
@@ -527,14 +566,11 @@ show_user (UmUser *user, UmUserPanelPrivate *d)
 
         lang = g_strdup (um_user_get_language (user));
         if (!lang)
-                lang = um_get_current_language ();
-        um_get_iter_for_language (model, lang, &iter);
+                lang = cc_common_language_get_current_language ();
+        cc_common_language_get_iter_for_language (model, lang, &iter);
         um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (widget), &iter);
         g_free (lang);
 
-        label = get_widget (d, "account-location-entry");
-        um_editable_entry_set_text (UM_EDITABLE_ENTRY (label), um_user_get_location (user));
-
         widget = get_widget (d, "account-fingerprint-notebook");
         label = get_widget (d, "account-fingerprint-label");
         label2 = get_widget (d, "account-fingerprint-value-label");
@@ -579,7 +615,7 @@ change_name_done (GtkWidget          *entry,
 
         text = um_editable_entry_get_text (UM_EDITABLE_ENTRY (entry));
 
-        if (g_strcmp0 (text, um_user_get_location (user)) != 0) {
+        if (g_strcmp0 (text, um_user_get_real_name (user)) != 0) {
                 um_user_set_real_name (user, text);
         }
 }
@@ -625,9 +661,9 @@ language_response (GtkDialog         *dialog,
         else {
                 lang = g_strdup (um_user_get_language (user));
                 if (!lang)
-                        lang = um_get_current_language ();
+                        lang = cc_common_language_get_current_language ();
         }
-        um_get_iter_for_language (model, lang, &iter);
+        cc_common_language_get_iter_for_language (model, lang, &iter);
         um_editable_combo_set_active_iter (UM_EDITABLE_COMBO (combo), &iter);
         g_free (lang);
 
@@ -635,27 +671,6 @@ language_response (GtkDialog         *dialog,
         gtk_widget_set_sensitive (combo, TRUE);
 }
 
-static gboolean
-finish_language_chooser (UmUserPanelPrivate *d)
-{
-        GtkWidget *combo;
-
-        combo = get_widget (d, "account-language-combo");
-        d->language_chooser = um_language_chooser_new ();
-        gtk_window_set_transient_for (GTK_WINDOW (d->language_chooser),
-                                      GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)));
-        g_signal_connect (d->language_chooser, "response",
-                          G_CALLBACK (language_response), d);
-        g_signal_connect (d->language_chooser, "delete-event",
-                          G_CALLBACK (gtk_widget_hide_on_delete), NULL);
-
-        gdk_window_set_cursor (gtk_widget_get_window (gtk_widget_get_toplevel (d->notebook)), NULL);
-        gtk_window_present (GTK_WINDOW (d->language_chooser));
-        gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
-
-        return FALSE;
-}
-
 static void
 language_changed (UmEditableCombo    *combo,
                   UmUserPanelPrivate *d)
@@ -664,7 +679,6 @@ language_changed (UmEditableCombo    *combo,
         GtkTreeIter iter;
         gchar *lang;
         UmUser *user;
-        GdkCursor *cursor;
 
         if (!um_editable_combo_get_active_iter (combo, &iter))
                  return;
@@ -687,12 +701,17 @@ language_changed (UmEditableCombo    *combo,
                 return;
         }
 
-        cursor = gdk_cursor_new (GDK_WATCH);
-        gdk_window_set_cursor (gtk_widget_get_window (gtk_widget_get_toplevel (d->notebook)),
-                               cursor);
-        gdk_cursor_unref (cursor);
+        d->language_chooser = um_language_chooser_new (gtk_widget_get_toplevel (d->main_box));
+        gtk_window_set_transient_for (GTK_WINDOW (d->language_chooser),
+                                      GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)));
+        g_signal_connect (d->language_chooser, "response",
+                          G_CALLBACK (language_response), d);
+        g_signal_connect (d->language_chooser, "delete-event",
+                          G_CALLBACK (gtk_widget_hide_on_delete), NULL);
 
-        g_idle_add ((GSourceFunc)finish_language_chooser, d);
+        gdk_window_set_cursor (gtk_widget_get_window (gtk_widget_get_toplevel (d->main_box)), NULL);
+        gtk_window_present (GTK_WINDOW (d->language_chooser));
+        gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
 }
 
 static void
@@ -704,43 +723,11 @@ change_password (GtkButton *button, UmUserPanelPrivate *d)
 
         um_password_dialog_set_user (d->password_dialog, user);
         um_password_dialog_show (d->password_dialog,
-                                  GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)));
+                                  GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)));
 
         g_object_unref (user);
 }
 
-static void
-change_email_done (UmEditableEntry    *e,
-                   UmUserPanelPrivate *d)
-{
-        const gchar *text;
-        UmUser *user;
-
-        user = get_selected_user (d);
-
-        text = um_editable_entry_get_text (e);
-
-        if (g_strcmp0 (text, um_user_get_email (user)) != 0) {
-                um_user_set_email (user, text);
-        }
-}
-
-static void
-change_location_done (GtkWidget         *entry,
-                      UmUserPanelPrivate *d)
-{
-        const gchar *text;
-        UmUser *user;
-
-        user = get_selected_user (d);
-
-        text = um_editable_entry_get_text (UM_EDITABLE_ENTRY (entry));
-
-        if (g_strcmp0 (text, um_user_get_location (user)) != 0) {
-                um_user_set_location (user, text);
-        }
-}
-
 static void
 change_fingerprint (GtkButton *button, UmUserPanelPrivate *d)
 {
@@ -752,7 +739,7 @@ change_fingerprint (GtkButton *button, UmUserPanelPrivate *d)
 
         label = get_widget (d, "account-fingerprint-value-label");
         label2 = get_widget (d, "account-fingerprint-button-label");
-        fingerprint_button_clicked (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)), label, label2, user);
+        fingerprint_button_clicked (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)), label, label2, user);
         g_object_unref (user);
 }
 
@@ -814,7 +801,7 @@ users_loaded (UmUserManager     *manager,
         GtkWidget *dialog;
 
         if (um_user_manager_no_service (d->um)) {
-                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->notebook)),
+                dialog = gtk_message_dialog_new (GTK_WINDOW (gtk_widget_get_toplevel (d->main_box)),
                                                  GTK_DIALOG_MODAL,
                                                  GTK_MESSAGE_OTHER,
                                                  GTK_BUTTONS_CLOSE,
@@ -888,7 +875,7 @@ on_permission_changed (GPermission *permission,
         is_authorized = g_permission_get_allowed (G_PERMISSION (d->permission));
         self_selected = um_user_get_uid (user) == geteuid ();
 
-        widget = get_widget (d, "add-user-button");
+        widget = get_widget (d, "add-user-toolbutton");
         gtk_widget_set_sensitive (widget, is_authorized);
         if (is_authorized) {
                 setup_tooltip_with_embedded_icon (widget, _("Create a user"), NULL, NULL);
@@ -908,7 +895,7 @@ on_permission_changed (GPermission *permission,
                 g_object_unref (icon);
         }
 
-        widget = get_widget (d, "delete-user-button");
+        widget = get_widget (d, "remove-user-toolbutton");
         gtk_widget_set_sensitive (widget, is_authorized && !self_selected);
         if (is_authorized) {
                 setup_tooltip_with_embedded_icon (widget, _("Delete the selected user"), NULL, NULL);
@@ -932,10 +919,14 @@ on_permission_changed (GPermission *permission,
         if (is_authorized) {
                 um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-type-combo")), TRUE);
                 remove_unlock_tooltip (get_widget (d, "account-type-combo"));
+                gtk_widget_set_sensitive (GTK_WIDGET (get_widget (d, "autologin-switch")), TRUE);
+                remove_unlock_tooltip (get_widget (d, "autologin-switch"));
         }
         else {
                 um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-type-combo")), FALSE);
                 add_unlock_tooltip (get_widget (d, "account-type-combo"));
+                gtk_widget_set_sensitive (GTK_WIDGET (get_widget (d, "autologin-switch")), FALSE);
+                add_unlock_tooltip (get_widget (d, "autologin-switch"));
         }
 
         if (is_authorized || self_selected) {
@@ -945,12 +936,6 @@ on_permission_changed (GPermission *permission,
                 um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "full-name-entry")), TRUE);
                 remove_unlock_tooltip (get_widget (d, "full-name-entry"));
 
-                um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "account-email-entry")), TRUE);
-                remove_unlock_tooltip (get_widget (d, "account-email-entry"));
-
-                um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "account-location-entry")), TRUE);
-                remove_unlock_tooltip (get_widget (d, "account-location-entry"));
-
                 um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-language-combo")), TRUE);
                 remove_unlock_tooltip (get_widget (d, "account-language-combo"));
 
@@ -966,12 +951,6 @@ on_permission_changed (GPermission *permission,
                 um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "full-name-entry")), FALSE);
                 add_unlock_tooltip (get_widget (d, "full-name-entry"));
 
-                um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "account-email-entry")), FALSE);
-                add_unlock_tooltip (get_widget (d, "account-email-entry"));
-
-                um_editable_entry_set_editable (UM_EDITABLE_ENTRY (get_widget (d, "account-location-entry")), FALSE);
-                add_unlock_tooltip (get_widget (d, "account-location-entry"));
-
                 um_editable_combo_set_editable (UM_EDITABLE_COMBO (get_widget (d, "account-language-combo")), FALSE);
                 add_unlock_tooltip (get_widget (d, "account-language-combo"));
 
@@ -1048,6 +1027,27 @@ match_user (GtkTreeModel *model,
         return result;
 }
 
+static void
+autologin_cell_data_func (GtkTreeViewColumn    *tree_column,
+                          GtkCellRenderer      *cell,
+                          GtkTreeModel         *model,
+                          GtkTreeIter          *iter,
+                          UmUserPanelPrivate   *d)
+{
+        gboolean is_autologin;
+
+        gtk_tree_model_get (model,
+                            iter,
+                            AUTOLOGIN_COL, &is_autologin,
+                            -1);
+
+        if (is_autologin) {
+                g_object_set (cell, "icon-name", "emblem-default-symbolic", NULL);
+        } else {
+                g_object_set (cell, "icon-name", NULL, NULL);
+        }
+}
+
 static void
 setup_main_window (UmUserPanelPrivate *d)
 {
@@ -1073,7 +1073,8 @@ setup_main_window (UmUserPanelPrivate *d)
                                     G_TYPE_BOOLEAN,
                                     G_TYPE_STRING,
                                     G_TYPE_BOOLEAN,
-                                    G_TYPE_INT);
+                                    G_TYPE_INT,
+                                    G_TYPE_BOOLEAN);
         model = (GtkTreeModel *)store;
         gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (model), sort_users, NULL, NULL);
         gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
@@ -1093,6 +1094,7 @@ setup_main_window (UmUserPanelPrivate *d)
                             TITLE_COL, title,
                             HEADING_ROW_COL, TRUE,
                             SORT_KEY_COL, 0,
+                            AUTOLOGIN_COL, FALSE,
                             -1);
         g_free (title);
 
@@ -1102,6 +1104,7 @@ setup_main_window (UmUserPanelPrivate *d)
                             TITLE_COL, title,
                             HEADING_ROW_COL, TRUE,
                             SORT_KEY_COL, 2,
+                            AUTOLOGIN_COL, FALSE,
                             -1);
         g_free (title);
 
@@ -1122,15 +1125,25 @@ setup_main_window (UmUserPanelPrivate *d)
 
         gtk_tree_view_append_column (GTK_TREE_VIEW (userlist), column);
 
+        cell = gtk_cell_renderer_pixbuf_new ();
+        column = gtk_tree_view_column_new ();
+        gtk_tree_view_column_pack_start (column, cell, FALSE);
+        gtk_tree_view_append_column (GTK_TREE_VIEW (userlist), column);
+        gtk_tree_view_column_set_cell_data_func (column,
+                                                 cell,
+                                                 (GtkTreeCellDataFunc) autologin_cell_data_func,
+                                                 d,
+                                                 NULL);
+
         selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (userlist));
         gtk_tree_selection_set_mode (selection, GTK_SELECTION_BROWSE);
         g_signal_connect (selection, "changed", G_CALLBACK (selected_user_changed), d);
         gtk_tree_selection_set_select_function (selection, dont_select_headings, NULL, NULL);
 
-        button = get_widget (d, "add-user-button");
+        button = get_widget (d, "add-user-toolbutton");
         g_signal_connect (button, "clicked", G_CALLBACK (add_user), d);
 
-        button = get_widget (d, "delete-user-button");
+        button = get_widget (d, "remove-user-toolbutton");
         g_signal_connect (button, "clicked", G_CALLBACK (delete_user), d);
 
         button = get_widget (d, "user-icon-nonbutton");
@@ -1145,14 +1158,11 @@ setup_main_window (UmUserPanelPrivate *d)
         button = get_widget (d, "account-password-button");
         g_signal_connect (button, "start-editing", G_CALLBACK (change_password), d);
 
-        button = get_widget (d, "account-email-entry");
-        g_signal_connect (button, "editing-done", G_CALLBACK (change_email_done), d);
-
         button = get_widget (d, "account-language-combo");
         g_signal_connect (button, "editing-done", G_CALLBACK (language_changed), d);
 
-        button = get_widget (d, "account-location-entry");
-        g_signal_connect (button, "editing-done", G_CALLBACK (change_location_done), d);
+        button = get_widget (d, "autologin-switch");
+        g_signal_connect (button, "notify::active", G_CALLBACK (autologin_changed), d);
 
         button = get_widget (d, "account-fingerprint-button");
         g_signal_connect (button, "clicked",
@@ -1164,7 +1174,7 @@ setup_main_window (UmUserPanelPrivate *d)
                 button = um_lock_button_new (d->permission);
                 gtk_widget_set_margin_top (button, 12);
                 gtk_widget_show (button);
-                box = get_widget (d, "userlist-vbox");
+                box = get_widget (d, "accounts-vbox");
                 gtk_box_pack_end (GTK_BOX (box), button, FALSE, FALSE, 0);
                 g_signal_connect (d->permission, "notify",
                                   G_CALLBACK (on_permission_changed), d);
@@ -1172,7 +1182,7 @@ setup_main_window (UmUserPanelPrivate *d)
                 d->lock_button = button;
         }
 
-        button = get_widget (d, "add-user-button");
+        button = get_widget (d, "add-user-toolbutton");
         names[0] = "changes-prevent-symbolic";
         names[1] = "changes-prevent";
         names[2] = NULL;
@@ -1181,7 +1191,7 @@ setup_main_window (UmUserPanelPrivate *d)
                                           _("To create a user,\nclick the * icon first"),
                                           "*",
                                           icon);
-        button = get_widget (d, "delete-user-button");
+        button = get_widget (d, "remove-user-toolbutton");
         setup_tooltip_with_embedded_icon (button,
                                           _("To delete the selected user,\nclick the * icon first"),
                                           "*",
@@ -1197,6 +1207,7 @@ um_user_panel_init (UmUserPanel *self)
         volatile GType type;
         const gchar *filename;
         GtkWidget *button;
+        GtkStyleContext *context;
 
         dbus_g_object_register_marshaller (fprintd_marshal_VOID__STRING_BOOLEAN,
                                            G_TYPE_NONE, G_TYPE_STRING, G_TYPE_BOOLEAN, G_TYPE_INVALID);
@@ -1209,29 +1220,35 @@ um_user_panel_init (UmUserPanel *self)
         type = um_editable_entry_get_type ();
         type = um_editable_combo_get_type ();
 
+        gtk_widget_set_size_request (GTK_WIDGET (self), -1, 350);
+
         d->builder = gtk_builder_new ();
         d->um = um_user_manager_ref_default ();
         d->authority = polkit_authority_get_sync (NULL, NULL);
 
         filename = UIDIR "/user-accounts-dialog.ui";
         if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-                filename = "../data/user-accounts-dialog.ui";
+                filename = "data/user-accounts-dialog.ui";
         }
         error = NULL;
         if (!gtk_builder_add_from_file (d->builder, filename, &error)) {
                 g_error ("%s", error->message);
                 g_error_free (error);
-                exit (1);
+                return;
         }
 
         setup_main_window (d);
-        d->login_options = um_login_options_new (d->builder);
         d->account_dialog = um_account_dialog_new ();
         d->password_dialog = um_password_dialog_new ();
         button = get_widget (d, "user-icon-button");
         d->photo_dialog = um_photo_dialog_new (button);
-        d->notebook = get_widget (d, "top-level-notebook");
-        gtk_widget_reparent (d->notebook, GTK_WIDGET (self));
+        d->main_box = get_widget (d, "accounts-vbox");
+        gtk_widget_reparent (d->main_box, GTK_WIDGET (self));
+
+        context = gtk_widget_get_style_context (get_widget (d, "list-scrolledwindow"));
+        gtk_style_context_set_junction_sides (context, GTK_JUNCTION_BOTTOM);
+        context = gtk_widget_get_style_context (get_widget (d, "add-remove-toolbar"));
+        gtk_style_context_set_junction_sides (context, GTK_JUNCTION_TOP);
 }
 
 static void
@@ -1259,9 +1276,9 @@ um_user_panel_dispose (GObject *object)
                 um_photo_dialog_free (priv->photo_dialog);
                 priv->photo_dialog = NULL;
         }
-        if (priv->login_options) {
-                um_login_options_free (priv->login_options);
-                priv->login_options = NULL;
+        if (priv->language_chooser) {
+                gtk_widget_destroy (priv->language_chooser);
+                priv->language_chooser = NULL;
         }
         if (priv->authority) {
                 g_object_unref (priv->authority);
